@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-from email import charset as Charset, encoders as Encoders
+from email import encoders, charset as CharSet
 from email.generator import Generator
 from email.mime.text import MIMEText
 from email.mime.multipart import MIMEMultipart
@@ -12,15 +12,15 @@ try:
 except ImportError:
     from StringIO import StringIO
 
-from .utils import forbid_multi_line_headers, make_msgid, to_bytestring
+from .compat import to_bytestring
+from .html2text import extract_text_from_html
+from .utils import string_types, forbid_multi_line_headers, make_msgid
 
 
-# Don't BASE64-encode UTF-8 messages so that we avoid unwanted attention from
-# some spam filters.
-Charset.add_charset('utf-8', Charset.SHORTEST, None, 'utf-8')
+# Don't BASE64-encode UTF-8 messages
+CharSet.add_charset('utf-8', CharSet.SHORTEST, None, 'utf-8')
 
-# Default MIME type to use on attachments (if it is not explicitly given
-# and cannot be guessed).
+# Default MIME type to use on attachments
 DEFAULT_ATTACHMENT_MIME_TYPE = 'application/octet-stream'
 
 
@@ -33,39 +33,53 @@ class EmailMessage(object):
     alternative_subtype = 'alternative'
     encoding = 'utf-8'
 
-    def __init__(self, subject='', text_content='', from_email=None, to=None, 
-            cc=None, bcc=None, html_content=None, attachments=None,
-            headers=None):
+    def __init__(self, subject='', text='', from_email=None, to=None,
+                 cc=None, bcc=None, reply_to=None,
+                 html=None, attachments=None, headers=None,
+                 text_content=None, html_content=None):
         """Initialize a single email message (which can be sent to multiple
         recipients).
 
         All strings used to create the message can be unicode strings
         (or UTF-8 bytestrings). The SafeMIMEText class will handle any
         necessary encoding conversions.
+
+        `text_content` and `html_content` parameters exists for backwards
+        compatibility. Use `text` and `html` instead.
         """
         to = to or []
-        if isinstance(to, basestring):
+        if isinstance(to, string_types):
             to = [to]
         self.to = list(to)
-        
+
         cc = cc or []
-        if isinstance(cc, basestring):
+        if isinstance(cc, string_types):
             cc = [cc]
         self.cc = list(cc)
-        
+
         bcc = bcc or []
-        if isinstance(bcc, basestring):
+        if isinstance(bcc, string_types):
             bcc = [bcc]
         self.bcc = list(bcc)
 
+        reply_to = reply_to or []
+        if isinstance(reply_to, string_types):
+            reply_to = [reply_to]
+        self.reply_to = list(reply_to)
+
         self.from_email = from_email
         self.subject = subject
-        self.text_content = text_content
-        self.html_content = html_content
         self.attachments = attachments or []
         self.extra_headers = headers or {}
 
-    def message(self):
+        text = text or text_content or ''
+        html = html or html_content or ''
+        if html and not text:
+            text = extract_text_from_html(html)
+        self.text = text
+        self.html = html
+
+    def render(self):
         msg = self._create_message()
         msg['Subject'] = self.subject
         msg['From'] = self.extra_headers.get('From', self.from_email)
@@ -79,8 +93,7 @@ class EmailMessage(object):
         if self.cc:
             msg['Cc'] = ', '.join(self.cc)
 
-        # Email header names are case-insensitive (RFC 2045), so we have to
-        # accommodate that when doing comparisons.
+        # Email header names are case-insensitive (RFC 2045)
         header_names = [key.lower() for key in self.extra_headers]
         if 'date' not in header_names:
             msg['Date'] = formatdate()
@@ -91,16 +104,16 @@ class EmailMessage(object):
                 continue
             msg[name] = value
         return msg
-    
+
     def as_string(self, unixfrom=False):
-        return self.message().as_string(unixfrom)
+        return self.render().as_string(unixfrom)
 
     def get_recipients(self):
         """Returns a list of all recipients of the email (includes direct
         addressees as well as Cc and Bcc entries).
         """
         return self.to + self.cc + self.bcc
-    
+
     def attach(self, filename=None, content=None, mimetype=None):
         """Attaches a file with the given filename and content. The filename
         can be omitted and the mimetype is guessed, if not provided.
@@ -109,7 +122,8 @@ class EmailMessage(object):
         into the resulting message attachments.
         """
         if isinstance(filename, MIMEBase):
-            assert content == mimetype == None
+            assert content == mimetype
+            assert mimetype is None
             self.attachments.append(filename)
         else:
             assert content is not None
@@ -123,26 +137,28 @@ class EmailMessage(object):
         self.attach(filename, content, mimetype)
 
     def _create_message(self):
-        text_content = ''
-        if self.text_content:
-            text_content = SafeMIMEText(to_bytestring(self.text_content,
-                self.encoding), self.content_subtype, self.encoding)
-        msg = text_content
-        
-        if self.html_content:
+        text = ''
+        if self.text:
+            text = SafeMIMEText(
+                to_bytestring(self.text, self.encoding),
+                self.content_subtype, self.encoding)
+        msg = text
+
+        if self.html:
             msg = SafeMIMEMultipart(_subtype=self.alternative_subtype,
-                encoding=self.encoding)
-            if text_content:
-                msg.attach(text_content)
-            
-            if self.html_content:
-                html_content = SafeMIMEText(to_bytestring(self.html_content,
-                    self.encoding), self.html_subtype, self.encoding)
-                msg.attach(html_content)
-        
+                                    encoding=self.encoding)
+            if text:
+                msg.attach(text)
+
+            if self.html:
+                html = SafeMIMEText(
+                    to_bytestring(self.html, self.encoding),
+                    self.html_subtype, self.encoding)
+                msg.attach(html)
+
         if self.attachments:
             _msg = SafeMIMEMultipart(_subtype=self.mixed_subtype,
-                encoding=self.encoding)
+                                     encoding=self.encoding)
             _msg.attach(msg)
             msg = _msg
             for attachment in self.attachments:
@@ -150,7 +166,7 @@ class EmailMessage(object):
                     msg.attach(attachment)
                 else:
                     msg.attach(self._create_attachment(*attachment))
-        
+
         return msg
 
     def _create_attachment(self, filename, content, mimetype=None):
@@ -164,21 +180,22 @@ class EmailMessage(object):
         attachment = self._create_mime_attachment(content, mimetype)
         if filename:
             attachment.add_header('Content-Disposition', 'attachment',
-                filename=filename)
+                                  filename=filename)
         return attachment
-    
+
     def _create_mime_attachment(self, content, mimetype):
         """Converts the content, mimetype pair into a MIME attachment object.
         """
         basetype, subtype = mimetype.split('/', 1)
         if basetype == 'text':
-            attachment = SafeMIMEText(to_bytestring(content, self.encoding),
+            attachment = SafeMIMEText(
+                to_bytestring(content, self.encoding),
                 subtype, self.encoding)
         else:
             # Encode non-text attachments with base64.
             attachment = MIMEBase(basetype, subtype)
             attachment.set_payload(content)
-            Encoders.encode_base64(attachment)
+            encoders.encode_base64(attachment)
         return attachment
 
 
@@ -196,12 +213,9 @@ class SafeMIMEText(MIMEText):
         """Return the entire formatted message as a string.
         Optional `unixfrom' when True, means include the Unix From_ envelope
         header.
-
-        This overrides the default as_string() implementation to not mangle
-        lines that begin with 'From '. See bug #13433 for details.
         """
         fp = StringIO()
-        g = Generator(fp, mangle_from_ = False)
+        g = Generator(fp, mangle_from_=False)
         g.flatten(self, unixfrom=unixfrom)
         return fp.getvalue()
 
@@ -209,7 +223,7 @@ class SafeMIMEText(MIMEText):
 class SafeMIMEMultipart(MIMEMultipart):
 
     def __init__(self, _subtype='mixed', boundary=None, _subparts=None,
-            encoding=None, **_params):
+                 encoding=None, **_params):
         self.encoding = encoding
         MIMEMultipart.__init__(self, _subtype, boundary, _subparts, **_params)
 
@@ -221,12 +235,8 @@ class SafeMIMEMultipart(MIMEMultipart):
         """Return the entire formatted message as a string.
         Optional `unixfrom' when True, means include the Unix From_ envelope
         header.
-
-        This overrides the default as_string() implementation to not mangle
-        lines that begin with 'From '. See bug #13433 for details.
         """
         fp = StringIO()
-        g = Generator(fp, mangle_from_ = False)
+        g = Generator(fp, mangle_from_=False)
         g.flatten(self, unixfrom=unixfrom)
         return fp.getvalue()
-
